@@ -33,6 +33,11 @@ div(
         withMathJax(),
         includeHTML("html/ndivergent.html")
       ),
+      tabPanel(
+        "energy",
+        withMathJax(),
+        includeHTML("html/energy.html")
+      ),
       tabPanel(
         "stepsize",
         includeHTML("html/stepsize.html")
